# Firehose lambda declaration
resource "aws_lambda_function" "firehorse_lambda" {
  source_code_hash = filebase64sha256(var.firehose_lambda_file)
  role             = aws_iam_role.fire_lambda_role.arn
  function_name    = var.firehose_lambda_name
  filename         = var.firehose_lambda_file
  memory_size      = var.lambda_memory_size
  timeout          = var.lambda_timeouts
  handler          = "Provided"
  runtime          = "provided"

  environment {
    variables = {
      SNS_TOPIC_ARN = aws_sns_topic.s3rius_sns_topic.arn,
      LOG_LEVEL     = "debug,hyper=error,rusoto_core=info",
      LOG_STYLE     = "none"
    }
  }
}

resource "aws_iam_role" "fire_lambda_role" {
  assume_role_policy = data.aws_iam_policy_document.fire_lambda_role_policy_doc.json
}

resource "aws_iam_policy" "fire_lambda_extra_doc" {
  path   = "/"
  policy = data.aws_iam_policy_document.fire_lambda_extra_doc.json
}


resource "aws_iam_role_policy_attachment" "fire_lambda_policy_attachment" {
  role       = aws_iam_role.fire_lambda_role.name
  policy_arn = aws_iam_policy.fire_lambda_extra_doc.arn
}

data "aws_iam_policy_document" "fire_lambda_role_policy_doc" {
  version = "2012-10-17"

  statement {
    effect = "Allow"
    actions = [
      "sts:AssumeRole"
    ]

    principals {
      type = "Service"
      identifiers = [
        "lambda.amazonaws.com"
      ]
    }
  }
}

data "aws_iam_policy_document" "fire_lambda_extra_doc" {
  statement {
    effect = "Allow"
    actions = [
      "logs:PutLogEvents",
      "logs:CreateLogStream",
      "logs:CreateLogGroup"
    ]
    resources = [
      aws_cloudwatch_log_group.fire_lamda_logs.arn
    ]
  }

  statement {
    effect = "Allow"
    actions = [
      "sns:Publish"
    ]
    resources = [
      aws_sns_topic.s3rius_sns_topic.arn
    ]
  }
}