resource "aws_glue_catalog_database" "glue_database" {
  name = "glue_database"
}

resource "aws_glue_catalog_table" "glue_table" {
  database_name = aws_glue_catalog_database.glue_database.name
  name          = "glue_table"

  storage_descriptor {
    location      = "s3://${aws_s3_bucket.bucket.bucket}"
    input_format  = "org.apache.hadoop.hive.ql.io.parquet.MapredParquetInputFormat"
    output_format = "org.apache.hadoop.hive.ql.io.parquet.MapredParquetOutputFormat"

    ser_de_info {
      name                  = "jsonSerDe"
      serialization_library = "org.apache.hadoop.hive.ql.io.parquet.serde.ParquetHiveSerDe"
      parameters = {
        "serialization.format" = 1
        "explicit.null"        = false
        "parquet.compression"  = "GZIP"
      }
    }

    columns {
      name = "timestamp"
      type = "bigint"
    }
    columns {
      name = "coords"
      type = "bigint"
    }
    columns {
      name = "temperature"
      type = "bigint"
    }
    columns {
      name = "humidity"
      type = "bigint"
    }
    columns {
      name = "pressure"
      type = "bigint"
    }
    columns {
      name = "city"
      type = "string"
    }
    columns {
      name = "country"
      type = "string"
    }
    columns {
      name = "ip_addr"
      type = "string"
    }
  }
}

resource "aws_iam_role_policy" "glue_firehose_role_policy" {
  role   = aws_iam_role.firehose_role.id
  policy = data.aws_iam_policy_document.glue_policy_doc.json
}

data "aws_iam_policy_document" "glue_policy_doc" {
  version = "2012-10-17"
  statement {
    effect = "Allow"
    actions = [
      "glue:GetTable",
      "glue:GetTableVersion",
      "glue:GetTableVersions"
    ]
    resources = [
      "*"
    ]
  }
}