resource "aws_lambda_function" "sns_lambda" {
  source_code_hash = filebase64sha256(var.firehose_lambda_file)
  role             = aws_iam_role.sns_lambda_role.arn
  memory_size      = var.lambda_memory_size
  function_name    = var.sns_lambda_name
  filename         = var.sns_lambda_file
  timeout          = var.lambda_timeouts
  handler          = "Provided"
  runtime          = "provided"

  environment {
    variables = {
      S3_BUCKET = aws_s3_bucket.bucket.bucket,
      LOG_LEVEL = "debug,hyper=error,rusoto_core=info",
      LOG_STYLE = "none"
    }
  }
}

resource "aws_sns_topic_subscription" "weather_updates_lambda_target" {
  topic_arn = aws_sns_topic.s3rius_sns_topic.arn
  protocol  = "lambda"
  endpoint  = aws_lambda_function.sns_lambda.arn
}

resource "aws_iam_role" "sns_lambda_role" {
  name               = var.sns_lambda_name
  assume_role_policy = data.aws_iam_policy_document.sns_lambda_role_policy_doc.json
}

resource "aws_iam_policy" "sns_lambda_extra_doc" {
  path   = "/"
  policy = data.aws_iam_policy_document.sns_lambda_extra_doc.json
}


resource "aws_iam_role_policy_attachment" "sns_lambda_policy_attachment" {
  role       = aws_iam_role.sns_lambda_role.name
  policy_arn = aws_iam_policy.sns_lambda_extra_doc.arn
}

data "aws_iam_policy_document" "sns_lambda_role_policy_doc" {
  version = "2012-10-17"

  statement {
    effect = "Allow"
    actions = [
      "sts:AssumeRole"
    ]

    principals {
      type = "Service"
      identifiers = [
        "lambda.amazonaws.com"
      ]
    }
  }
}

data "aws_iam_policy_document" "sns_lambda_extra_doc" {
  statement {
    effect = "Allow"
    actions = [
      "logs:PutLogEvents",
      "logs:CreateLogStream",
      "logs:CreateLogGroup"
    ]
    resources = [
      aws_cloudwatch_log_group.sns_lamda_logs.arn
    ]
  }

  statement {
    effect = "Allow"
    actions = [
      "s3:AbortMultipartUpload",
      "s3:GetBucketLocation",
      "s3:GetObject",
      "s3:ListBucket",
      "s3:ListBucketMultipartUploads",
      "s3:PutObject"
    ]
    resources = [
      aws_s3_bucket.bucket.arn,
      "${aws_s3_bucket.bucket.arn}/*"
    ]
  }
}