resource "aws_sqs_queue" "s3rius_sqs_queue" {
  name                      = "s3rius-sqs"
  message_retention_seconds = 600
}


resource "aws_sns_topic_subscription" "weather_updates_sqs_target" {
  topic_arn = aws_sns_topic.s3rius_sns_topic.arn
  protocol  = "sqs"
  endpoint  = aws_sqs_queue.s3rius_sqs_queue.arn
}

resource "aws_sqs_queue_policy" "sqs_publish_policy" {
  queue_url = aws_sqs_queue.s3rius_sqs_queue.id
  policy    = data.aws_iam_policy_document.sqs_send_message_policy_doc.json
}

data "aws_iam_policy_document" "sqs_send_message_policy_doc" {
  statement {
    effect = "Allow"
    actions = [
      "sqs:SendMessage"
    ]
    principals {
      type = "AWS"
      identifiers = [
        "*"
      ]
    }
    resources = [
      aws_sqs_queue.s3rius_sqs_queue.arn
    ]
    condition {
      test     = "ArnEquals"
      variable = "aws:SourceArn"
      values = [
        aws_sns_topic.s3rius_sns_topic.arn
      ]
    }
  }
}

