#!/bin/sh
ERR='\033[0;31m'
WARNING='\033[0;33m'
NC='\033[0m' # No Color

lambdas=( "firehose_lambda_function" "sns_lambda_function" )


function build_lambda(){
    for lambda in "${lambdas[@]}"; do
      lambda_path="./lambdas/$lambda/"
      # Going in lambda directory
      pushd "$lambda_path" || { printf "${ERR}Unknown lambda path:${NC}${lambda_path}\n"; exit 1; }
      # Building lambda function with make
      make || { printf "${ERR}Can't verify lambda package${NC}\n"; exit 1; }
      make install zip_name="$lambda" || { printf "${ERR}Can't pack lambda zip${NC}\n"; exit 1; }
      # Going back to start location
      popd || exit 1
      mv "$lambda_path/$lambda.zip" .
      # Exporting variable for terraform
      eval "export TF_VAR_${lambda}=${lambda}.zip"
  done
}

# Remove lambda .zip package
function rm_lambdas() {
    # Iterate over input parameters
    for lambda in "${lambdas[@]}";do
        # Check if lambda exists
        if [[ -f "${lambda}.zip" ]];then
            # Print message and delete
            printf "${WARNING}Removing lambda zip_file: '${lambda}'${NC}\n"
            rm "${lambda}.zip"
        else
            # Lambda was not found
            printf "${ERR}Lambda ${lambda} was not found${NC}\n"
        fi
    done
}

function main(){
    # Build and pack in zip firehose lambda
    build_lambda
    # Format files.
    terraform fmt -recursive
    # Install all modules, plugin and other stuff
    terraform init
    # Create plan with some variables injected
    terraform apply
}

# Export s3 bucket name to be same as in second task.
if [[ -n "$1" ]]; then
    export TF_VAR_s3_bucket_name=$1
fi

# Remove packaged lambdas on exit
trap rm_lambdas EXIT TERM
main
