#[macro_use]
extern crate log;

/// Main processing module.
/// All processing function placed here
pub mod processors;

use std::error::Error;
use tokio::runtime::Runtime;

/// Common error type.
/// It can be used with any error that
/// implements `Send` + `Sync` traits.
type LambdaError = Box<dyn Error + Send + Sync + 'static>;

/// This function starting point of the binary. It points the lambda to execution function.
/// Real lambda processor located in `processors` module.
fn main() -> Result<(), LambdaError> {
    dotenv::dotenv().ok();

    let env = env_logger::Env::default()
        .filter_or("LOG_LEVEL", "info")
        .write_style_or("LOG_STYLE", "never");

    env_logger::init_from_env(env);

    let mut rt = Runtime::new().expect("can't start Tokio runtime");
    let handler = lambda::handler_fn(processors::process);
    rt.block_on(lambda::run(handler))?;
    Ok(())
}
