data "aws_availability_zones" "available" {
  state = "available"
}

resource "aws_autoscaling_group" "s3rius-asg-processors" {
  max_size             = 3
  min_size             = 0
  force_delete         = true
  launch_configuration = aws_launch_configuration.asg-launch-config.name
  availability_zones   = data.aws_availability_zones.available.names

  health_check_type = "ELB"
  load_balancers = [
    aws_elb.load_balancer.name
  ]
}

resource "aws_autoscaling_policy" "scale_up_policy" {
  name                   = "sqs-asg-scale-up-policy"
  scaling_adjustment     = 1
  autoscaling_group_name = aws_autoscaling_group.s3rius-asg-processors.name
  adjustment_type        = "ChangeInCapacity"
  cooldown               = 300
}

resource "aws_autoscaling_policy" "scale_down_policy" {
  name                   = "sqs-asg-scale-down-policy"
  scaling_adjustment     = -1
  autoscaling_group_name = aws_autoscaling_group.s3rius-asg-processors.name
  adjustment_type        = "ChangeInCapacity"
  cooldown               = 300
}


resource "aws_elb" "load_balancer" {
  name = "terraform-asg-example"
  security_groups = [
    aws_security_group.outbound_traffic_security.id
  ]

  availability_zones = data.aws_availability_zones.available.names

  health_check {
    target              = "HTTP:${var.ec2_port}/"
    interval            = 30
    timeout             = 3
    healthy_threshold   = 2
    unhealthy_threshold = 2
  }

  # This adds a listener for incoming HTTP requests.
  listener {
    lb_port           = var.elb_port
    lb_protocol       = "http"
    instance_port     = var.ec2_port
    instance_protocol = "http"
  }
}

resource "aws_security_group" "inbound_traffic_security" {
  name = "inbound-ec2"

  ingress {
    from_port = var.elb_port
    to_port   = var.elb_port
    protocol  = "tcp"
    cidr_blocks = [
      "0.0.0.0/0"
    ]
  }

  ingress {
    from_port = 22
    to_port   = 22
    protocol  = "tcp"
    cidr_blocks = [
      "0.0.0.0/0"
    ]
  }
}

resource "aws_security_group" "outbound_traffic_security" {
  name = "outbound-ec2"

  # Allow all outbound
  egress {
    from_port = 0
    to_port   = 0
    protocol  = "-1"
    cidr_blocks = [
      "0.0.0.0/0"
    ]
  }

  # Inbound HTTP from anywhere
  ingress {
    from_port = var.ec2_port
    to_port   = var.ec2_port
    protocol  = "tcp"
    cidr_blocks = [
      "0.0.0.0/0"
    ]
  }
}

