resource "aws_cloudwatch_log_group" "s3_lamda_logs" {
  name              = "/aws/lambda/${aws_lambda_function.s3_lambda.function_name}"
  retention_in_days = 1
}


resource "aws_cloudwatch_log_group" "asg_ec2_logs" {
  name              = "ec2_logs"
  retention_in_days = 1
}

resource "aws_cloudwatch_metric_alarm" "sqs-asg-metric-alarm" {
  alarm_name          = "SQS-message-alarm"
  comparison_operator = "GreaterThanOrEqualToThreshold"
  evaluation_periods  = "1"
  metric_name         = "NumberOfMessagesSent"
  namespace           = "AWS/SQS"
  period              = "60"
  statistic           = "SampleCount"
  threshold           = "2"

  dimensions = {
    QueueName = aws_sqs_queue.s3rius_sqs_queue.name
  }

  alarm_description = "This metric monitors SQS messages and fire ec2 from asg"
  alarm_actions = [
    aws_autoscaling_policy.scale_up_policy.arn
  ]
}

resource "aws_cloudwatch_metric_alarm" "cpu-asg-metric-alarm" {
  alarm_name          = "CPU-message-alarm"
  evaluation_periods  = 2
  comparison_operator = "LessThanThreshold"
  metric_name         = "CPUUtilization"
  namespace           = "AWS/EC2"
  period              = "120"
  statistic           = "Average"
  threshold           = "5"

  dimensions = {
    AutoScalingGroupName = aws_autoscaling_group.s3rius-asg-processors.name
  }

  alarm_description = "This metric monitors CPU utilization for scaling down"
  alarm_actions = [
    aws_autoscaling_policy.scale_down_policy.arn
  ]
}