resource "aws_launch_configuration" "asg-launch-config" {
  name          = "s3rius-autoscaling-launch-config"
  image_id      = "ami-0a9e2b8a093c02922"
  instance_type = "t2.micro"
  security_groups = [
    aws_security_group.inbound_traffic_security.id,
    aws_security_group.outbound_traffic_security.id
  ]

  iam_instance_profile = aws_iam_instance_profile.s3rius_profile.id
  key_name             = aws_key_pair.aws_key_pair.key_name
  user_data            = data.template_file.asg_user_data.rendered
  depends_on = [
    aws_s3_bucket_object.application_data,
  ]
}

resource "aws_key_pair" "aws_key_pair" {
  key_name   = "aws_key_pair"
  public_key = file(var.ec2_ssh_key_file)
}

data "template_file" "asg_user_data" {
  template = file("${path.module}/utils/asg_user_data.sh")
  vars = {
    meta_bucket         = aws_s3_bucket.asg_meta_bucket.bucket
    application_key     = var.ec2_application_s3_key
    sqs_queue_id        = aws_sqs_queue.s3rius_sqs_queue.id
    aws_region          = var.aws_region
    cloudwatch_conf_key = var.ec2_cloudwatch_conf_key
    s3_bucket           = aws_s3_bucket.s3_weather_bucket.bucket
    sns_topic           = aws_sns_topic.asg-weather-topic.arn
  }
}


resource "aws_iam_instance_profile" "s3rius_profile" {
  name = "s3rius"
  role = aws_iam_role.ec2_profile_role.name
}

resource "aws_iam_role" "ec2_profile_role" {
  name               = "ec2_profile_role"
  path               = "/"
  assume_role_policy = data.aws_iam_policy_document.ec2_role_doc.json
}

resource "aws_iam_role_policy_attachment" "ec2_extra_role_policy" {
  role       = aws_iam_role.ec2_profile_role.name
  policy_arn = aws_iam_policy.ec2_extra_policy.arn
}

resource "aws_iam_policy" "ec2_extra_policy" {
  path   = "/"
  policy = data.aws_iam_policy_document.ec2_extra_doc.json
}


data "aws_iam_policy_document" "ec2_role_doc" {
  version = "2012-10-17"

  statement {
    actions = [
      "sts:AssumeRole"
    ]

    principals {
      identifiers = [
        "ec2.amazonaws.com"
      ]
      type = "Service"
    }

    effect = "Allow"
  }
}

data "aws_iam_policy_document" "ec2_extra_doc" {
  version = "2012-10-17"

  statement {
    effect = "Allow"
    actions = [
      "s3:GetBucketLocation",
      "s3:GetObject",
      "s3:ListBucket",
      "s3:ListBucketMultipartUploads",
    ]
    resources = [
      aws_s3_bucket.asg_meta_bucket.arn,
      "${aws_s3_bucket.asg_meta_bucket.arn}/*",
      aws_s3_bucket.s3_weather_bucket.arn,
      "${aws_s3_bucket.s3_weather_bucket.arn}/*"

    ]
  }

  statement {
    effect = "Allow"
    actions = [
      "sqs:*"
    ]
    resources = [
      aws_sqs_queue.s3rius_sqs_queue.arn
    ]
  }

  statement {
    effect = "Allow"
    actions = [
      "sns:Publish",
    ]
    resources = [
      aws_sns_topic.asg-weather-topic.arn
    ]
  }

}