resource "aws_lambda_function" "s3_lambda" {
  source_code_hash = filebase64sha256(var.s3_lambda_zip)
  role             = aws_iam_role.s3_lambda_role.arn
  memory_size      = var.lambda_memory_size
  timeout          = var.lambda_timeout
  function_name    = var.s3_lambda_name
  filename         = var.s3_lambda_zip
  handler          = "Provided"
  runtime          = "provided"

  environment {
    variables = {
      SQS_QUEUE_ID = aws_sqs_queue.s3rius_sqs_queue.id,
      LOG_LEVEL    = "debug,hyper=error,rusoto_core=info",
      LOG_STYLE    = "none"
    }
  }
}

resource "aws_lambda_permission" "allow_bucket" {
  statement_id  = "AllowExecutionFromS3Bucket"
  action        = "lambda:InvokeFunction"
  function_name = aws_lambda_function.s3_lambda.arn
  principal     = "s3.amazonaws.com"
  source_arn    = aws_s3_bucket.s3_weather_bucket.arn
}

resource "aws_iam_role" "s3_lambda_role" {
  name               = var.s3_lambda_name
  assume_role_policy = data.aws_iam_policy_document.s3_lambda_policy_doc.json
}

resource "aws_iam_role_policy_attachment" "s3_lambda_policy_attachment" {
  role       = aws_iam_role.s3_lambda_role.name
  policy_arn = aws_iam_policy.s3_lambda_extra_doc.arn
}

resource "aws_iam_policy" "s3_lambda_extra_doc" {
  path   = "/"
  policy = data.aws_iam_policy_document.s3_lambda_extra_doc.json
}


data "aws_iam_policy_document" "s3_lambda_policy_doc" {
  version = "2012-10-17"
  statement {
    effect = "Allow"
    actions = [
      "sts:AssumeRole",
    ]
    principals {
      identifiers = [
        "lambda.amazonaws.com"
      ]
      type = "Service"
    }
  }
}

data "aws_iam_policy_document" "s3_lambda_extra_doc" {
  statement {
    effect = "Allow"
    actions = [
      "logs:PutLogEvents",
      "logs:CreateLogStream",
      "logs:CreateLogGroup"
    ]
    resources = [
      aws_cloudwatch_log_group.s3_lamda_logs.arn
    ]
  }

  statement {
    effect = "Allow"
    actions = [
      "sqs:SendMessage",
    ]
    resources = [
      aws_sqs_queue.s3rius_sqs_queue.arn
    ]
  }
}