#!/bin/sh
ERR='\033[0;31m'
WARNING='\033[0;33m'
NC='\033[0m' # No Color

key_name="ec2_key.pub"
applications=( "s3_lambda_function" "ec2_sqs_listener" )


function build_application(){
    for application in "${applications[@]}"; do
      application_path="./applications/$application/"
      # Going in application directory
      pushd "$application_path" || { printf "${ERR}Unknown application path:${NC}${application_path}\n"; exit 1; }
      # Building application function with make
      make || { printf "${ERR}Can't verify application package${NC}\n"; popd; exit 1; }
      make install zip_name="$application" || { printf "${ERR}Can't pack application zip${NC}\n"; popd; exit 1; }
      # Going back to start location
      popd || exit 1
      mv "$application_path/$application.zip" .
      # Exporting variable for terraform
      eval "export TF_VAR_${application}=${application}.zip"
  done
}

# Remove application .zip package
function rm_applications() {
    # Iterate over input parameters
    for application in "${applications[@]}";do
        # Check if application exists
        if [[ -f "${application}.zip" ]];then
            # Print message and delete
            printf "${WARNING}Removing application zip_file: '${application}'${NC}\n"
            rm "${application}.zip"
        else
            # Lambda was not found
            printf "${ERR}Application ${application}.zip was not found${NC}\n"
        fi
    done
}

function cleanup() {
    rm_applications
    printf "${WARNING}Removing ec2 public key${NC}\n"
    rm -v "./${key_name}"
}

function copy_ssh_key() {
    cp ~/.ssh/id_rsa.pub "./${key_name}"
    printf "${WARNING}ssh public key copied in build directory${NC}\n"
    export TF_VAR_ec2_ssh_key_file="./${key_name}"
}

function main(){
    copy_ssh_key
    # Build and pack in zip firehose application
    build_application
    # Format files.
    terraform fmt -recursive
    # Install all modules, plugin and other stuff
    terraform init
    # Create plan with some variables injected
    terraform apply
}

# Export s3 bucket name to be same as in second task.
if [[ -n "$1" ]]; then
    export TF_VAR_s3_bucket_name=$1
fi

# Remove packaged applications on exit
trap cleanup EXIT TERM
main
